@@ -1841,7 +1841,7 @@ pygvfs_uris_match(PyObject *self, PyObject *args, PyObject *kwargs)
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs,
 				     "ss:gnomevfs.uris_match",
-				     kwlist, &uri1, uri2))
+				     kwlist, &uri1, &uri2))
 	return NULL;
     retval = gnome_vfs_uris_match(uri1, uri2);
     py_retval = retval? Py_True : Py_False;
